@@ -69,6 +69,11 @@ int main(int argc, char *argv[])
         }
     }
     if (getuid() != 0) {
+        // For now only sudo can run this program
+        QMessageBox::critical(nullptr, QObject::tr("Error"),
+            QObject::tr("You must run this program with admin access."));
+        exit(EXIT_FAILURE);
+        
         if (!QFile::exists("/usr/bin/pkexec") && !QFile::exists("/usr/bin/gksu")) {
             QMessageBox::critical(nullptr, QObject::tr("Error"),
                                   QObject::tr("You must run this program with admin access."));
