@@ -41,7 +41,7 @@
         <location filename="mainwindow.ui" line="173"/>
         <location filename="ui_mainwindow.h" line="981"/>
         <source>Reenter password for new user</source>
-        <translation>Insira a senha novamente para o novo usuário</translation>
+        <translation>Insira novamente a mesma senha para o novo usuário</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="182"/>
@@ -53,7 +53,7 @@
         <location filename="mainwindow.ui" line="198"/>
         <location filename="ui_mainwindow.h" line="986"/>
         <source>Username of new user</source>
-        <translation>Nomedeusuario do novo usuário</translation>
+        <translation>Nome de usuário para o novo usuário</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="201"/>
@@ -67,7 +67,7 @@
         <location filename="ui_mainwindow.h" line="990"/>
         <location filename="ui_mainwindow.h" line="1020"/>
         <source>Enter username of new user</source>
-        <translation>Informe o nomedeusuario do novo usuário</translation>
+        <translation>Insira o nome de usuário do novo usuário</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="223"/>
@@ -107,7 +107,7 @@
         <location filename="mainwindow.ui" line="290"/>
         <location filename="ui_mainwindow.h" line="1003"/>
         <source>Delete User Account</source>
-        <translation>Excluir a Conta de Usuário</translation>
+        <translation>Excluir Uma Conta de Usuário</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="333"/>
@@ -171,7 +171,7 @@
         <location filename="mainwindow.ui" line="519"/>
         <location filename="ui_mainwindow.h" line="1026"/>
         <source>new password</source>
-        <translation>Nova senha</translation>
+        <translation>nova senha</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="535"/>
@@ -343,7 +343,7 @@
         <location filename="mainwindow.ui" line="944"/>
         <location filename="ui_mainwindow.h" line="1091"/>
         <source>Select to copy and then delete differences</source>
-        <translation>Selecione para copiar e em seguida apagar as diferenças</translation>
+        <translation>Selecione para copiar, em seguida, apague as diferenças</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="947"/>
